#
# spec file for package sipp
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sipp
Version:        3.6.1
Release:        bp156.3.7
Summary:        A SIP protocol testing tool
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Other
URL:            https://github.com/SIPp/sipp
Source:         https://github.com/SIPp/sipp/releases/download/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  help2man
BuildRequires:  libpcap-devel
BuildRequires:  lksctp-tools-devel
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(libssl)

%description
Sipp is a performance testing tool for the SIP protocol. Its main features are
basic SIPStone scenarios, TCP/UDP transport, customizable (xml based) scenarios,
dynamic adjustement of call-rate and a comprehensive set of real-time
statistics.

%prep
%setup -q
## FIXME: cmake oot-builds is broken
cp version.h src

%build
%cmake \
    -DUSE_GSL=1 \
    -DUSE_PCAP=1 \
    -DUSE_SSL=1 \
    -DUSE_SCTP=1
%make_build

%install
%cmake_install
## FIXME: manpage installation should be handled by cmake
install -Dpm 0644 %{name}.1 %{buildroot}/%{_mandir}/man1/%{name}.1

%files
%license LICENSE.txt
%doc CHANGES.md README.md THANKS
%{_bindir}/%{name}
%{_mandir}/man1/sipp.1%{?ext_man}

%changelog
* Sun Sep 20 2020 Martin Hauke <mardnh@gmx.de>
- Switch from autotools to cmake
- Update to version 3.6.1
  * Consistently unescape XML attributes when loading scenario
  * Fix buffer overflow in screen output
  * Fix nonce count in auth headers
  * Fix parser warning when trying to access 0-byte SDP body
  * Improve provided sipp.dtd file, and XML fixes
    Make it easier to deal with large SIP packets by adding an
    optional CPPFLAGS=-DSIPP_MAX_MSG_SIZE=262144 flag
* Wed Jun 19 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 3.6.0
  * Automatic filenames (trace files, error files, etc..) are now
    created in the current working directory instead of in the
    directory of the scenario file.
  * Only validates SSL certficate if CA-file is separately specified.
  * Fix `[routes]` header in UAS scenario's.
  * last\_Keyword does not search in SIP body anymore
* Sun Jul 29 2018 mardnh@gmx.de
- Fix license
* Wed Jul 18 2018 mardnh@gmx.de
- Update to version 3.5.2
  * Fix lots of build issues, mainly with ncurses/curses/tinfo
    and openssl.
  * Better parsing of Contact header. (Issue #234.)
  * Proper retrying of media ports during startup. (Issue #276.)
- Remove patch:
  * sipp-3.5.1-ncurses-ssl.patch (fixed upstream)
* Wed Apr  4 2018 jamesp@vicidial.com
- Made new ncurses/openssl patch for Leap 15.0
- Modified spec file to generate man page
- removed old ncurses patch: sipp-3.5.1-ncurses.patch
* Wed Apr  4 2018 jamesp@vicidial.com
- Update to SIPp v.3.5.1
- Remove old ncurses patch: sipp-3.3-ncurses.patch
- Make new ncurses patch: sipp-3.5.1-ncurses.patch
- Update spec file to a more modern standard
* Sun Jun 23 2013 reddwarf@opensuse.org
- Update to 3.3
* Thu Aug 12 2010 reddwarf@opensuse.org
- Initial package
